package cz.muni.fi.pa165.sampledata;

import com.google.common.hash.Hashing;
import cz.muni.fi.pa165.entity.PlayerEntity;
import cz.muni.fi.pa165.entity.TeamEntity;
import cz.muni.fi.pa165.enums.CountryEnum;
import cz.muni.fi.pa165.services.player.PlayerService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.crypto.argon2.Argon2PasswordEncoder;
import org.springframework.security.crypto.password.PasswordEncoder;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;

import java.io.IOException;
import java.nio.charset.StandardCharsets;

/**
 * @author Adrián Piaček
 */
@Component
@Transactional //transactions are handled on facade layer
public class SampleDataLoadingFacadeImpl implements SampleDataLoadingFacade {

    final static Logger log = LoggerFactory.getLogger(SampleDataLoadingFacadeImpl.class);

    @Autowired
    private PlayerService playerService;

    @Override
    @SuppressWarnings("unused")
    public void loadData() throws IOException {

        TeamEntity team = new TeamEntity();
        team.setName("Autisti");
        PlayerEntity crimsix = player("9384b466-badf-40ca-bbeb-4d8f6eb98042", "Ian Porter", "poter",
                "heslo", true, CountryEnum.AFGHANISTAN,5,6,7);

        PlayerEntity JJoNak = player("6e374a4e-5213-4581-847c-45f9e73ffe90", "Bang Seong-hyun ", "bang",
                "heslo", true, CountryEnum.ALBANIA,15,25,100);
        log.info("Loaded Sample Players.");
    }

    private PlayerEntity player(String uuid, String name, String username, String password, boolean admin,
                                CountryEnum country, int killStat, int deathStat, int assistStat) {
        PlayerEntity player = new PlayerEntity();
        player.setId(uuid);
        player.setName(name);
        player.setUsername(username);
        String sha256hex = Hashing.sha256().hashString(password, StandardCharsets.UTF_8).toString();
        player.setPasswordHash(sha256hex);
        player.setAdmin(admin);
        player.setCountry(country);
        player.setKillStat(killStat);
        player.setDeathStat(deathStat);
        player.setAssistStat(assistStat);
        playerService.create(player);
        return player;
    }

}
